
# Slot: id




URI: [core:id](https://w3id.org/linkml/tests/core/id)


## Domain and Range

None &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)
 * [Agent](Agent.md)
